# Contributing to the OpenAndroidInstaller project

💖 First of all: thank you for contributing to the OpenAndroidInstaller! Great that you are here!

This document contains some resources which should help you in doing that.

All kinds of contributions are welcome. These include:
- Fix and improve texts in configs and in the application.
- Test the tool for a supported device.
- Create a config for a new device.
- Test the application on your computer and/or device.
- Contribute an application build for a new platform.
- Add features and/or improve the code base.
- Report bugs.

## Code Of Conduct

Everyone who contributes to the project must follow [our code of conduct](https://github.com/openandroidinstaller-dev/openandroidinstaller/blob/main/CODE_OF_CONDUCT.md).
If you notice any violations, please reach out to us via the ways described in the code of conduct.

## How to Contribute

### Report a bug

Oops 😅 Thank you for catching a bug 🐛.
Please report this bug to us:

1. Ensure the bug was not already reported by searching through our [Issues](https://github.com/openandroidinstaller-dev/openandroidinstaller/issues).
2. If you can't find a bug report for your bug, please [open a new one](https://github.com/openandroidinstaller-dev/openandroidinstaller/issues/new/choose). Please choose **Bug Report** here, add **a title and clear description** and fill in the blanks.

For more information on how to write a good bug report, [check out the atom contribution guidelines](https://github.com/atom/atom/blob/master/CONTRIBUTING.md#how-do-i-submit-a-good-bug-report)

### The OpenAndroidInstaller "should to X" or is behaving weird / unintuitively / not doing what you want?

If the OpenAndroidInstaller is behaving unintuitively, feels weird, doesn't do something you think it should or similar, please [open an issue](https://github.com/openandroidinstaller-dev/openandroidinstaller/issues/new/choose) if there doesn't exist one yet.

We cannot guarantee that we can implement every feature you want, but we are always happy to discuss them and try to figure out how they might fit into the project.

If you cannot figure out how to do something with the OpenAndroidInstaller you should be able to do, we consider [this a bug](#report-a-bug).

### I don't understand the documentation 😕

If the documentation is unintuitive, we consider [this a bug](#report-a-bug).

If the documentation is missing something, we consider [this a bug](#report-a-bug).

If the documentation does not make you happy, we consider [this a bug](#report-a-bug).

### Write code / documentation to close issues

If you want to write code or documentation, please take a look at our issues.
We try to make them somewhat clear, but if you do not understand what an issue means, please ask us.
We sometimes tag issues as "good first issue", these could be interesting if this is you first contribution.

If you have an issue that you understand and want to work on, feel free to do so. If you leave a short message in the issue thread, we can make sure that we do not have multiple people working on the same issue.

Once you have a fix, **open a new pull request**. We will try to review your pull request as quick as possible.

To make sure we can merge it quickly, you can do a few things to help us:

1. Please make sure that the PR description includes all information we need to review this pull request (for example the issue this fixes, how it works).
2. Make sure that our linters, style checkers and tests pass. You can run them by running `make test`.
3. Make sure that branch can be merged into the dev branch

### Write code for new features 🚀

If you want to write code for something that is not already [described in an issue](https://github.com/openandroidinstaller-dev/openandroidinstaller/issues), please open an issue first and communicate that you are working on it.
Especially if it's more than a small bugfix for an obvious bug.
We might have some opinions on whether / how your feature should be included into the OpenAndroidInstaller.

If you do not open an issue first, we might have a lot of review comments that need to be addressed before we can merge your pull request or even have to close the PR entirely because we do not want to include the feature.

Opening an issue first also allows other users to comment on it, often leading to a better result.

### Write tests & documentation 🧪

If you want to write tests & documentation for existing features / behavior, always feel free to do so and open a pull request.
Here, we would also appreciate if you opened an issue first to avoid duplicate work.
If you have any questions while doing to, please open an issue or write us an email.
